/************************************************************************/
/*  Routines to read box file.						*/
/*									*/
/*	Pete Lombard							*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2003 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: get_box.c,v 1.1 2003/10/29 21:17:54 lombard Exp $ ";
#endif

#include <stdio.h>
#include <string.h>

#include "externals.h"
#include "procs.h"

#define	LINELEN 255

int get_box( VERTEX **p_points, WINDOW **p_window)
{
    FILE *fp;
    INT_TIME *p_it;
    static WINDOW window;
    char line[LINELEN+1];
    char date_str[40], dur_str[20];
    int npoints;
    
    *p_window = NULL;
    if ((fp = fopen(box_file, "r")) == NULL) {
	fprintf(info, "Unable to open box file %s\n", box_file);
	exit(1);
    }
    
    if (fgets(line, LINELEN, fp) == NULL) return 0;  /* empty file is OK */
    if (sscanf(line, "%s", date_str) == 1 && (p_it = parse_date(date_str)))
	window.start = *p_it;
    else {
	fprintf(info, "Error reading box file start time\n");
	exit(1);
    }
    if (fgets(line, LINELEN, fp) == NULL) {
	fprintf(info, "Error: box file missing duration and points\n");
	exit(1);
    }
    if (sscanf(line, "%s", date_str) == 1 && (p_it = parse_date(date_str)))
	window.end = *p_it;
    else {
	fprintf(info, "Error reading box file end time\n");
	exit(1);
    }
    window.event = NULL;
    
    npoints = read_polygon(fp, p_points);
    if (npoints < 3) {
	fprintf(info, "Error: less than 3 points in box file; not a polygon\n");
	exit(1);
    }
    
    *p_window = &window;
    return(npoints);
}
